@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     flask_marshmallow
     ~~~~~~~~~~~~~~~~~
@@ -7,7 +6,7 @@
     with your Flask application.
 """
 import warnings
-from distutils.version import LooseVersion
+from packaging.version import Version
 
 from marshmallow import fields as base_fields, exceptions, pprint
 
@@ -30,8 +29,8 @@ else:
     else:
         has_sqla = True
 
-__version__ = "0.13.0"
-__version_info__ = tuple(LooseVersion(__version__).version)
+__version__ = "0.15.0"
+__version_info__ = Version(__version__).release
 __all__ = ["EXTENSION_NAME", "Marshmallow", "Schema", "fields", "exceptions", "pprint"]
 
 EXTENSION_NAME = "flask-marshmallow"
@@ -48,7 +47,7 @@ def _attach_fields(obj):
         setattr(obj, attr, getattr(fields, attr))
 
 
-class Marshmallow(object):
+class Marshmallow:
     """Wrapper class that integrates Marshmallow with a Flask application.
 
     To use it, instantiate with an application::
@@ -71,7 +70,7 @@ class Marshmallow(object):
             author = ma.Nested(AuthorSchema)
 
             links = ma.Hyperlinks({
-                'self': ma.URLFor('book_detail', id='<id>'),
+                'self': ma.URLFor('book_detail', values=dict(id='<id>')),
                 'collection': ma.URLFor('book_list')
             })
 
@@ -112,7 +111,7 @@ class Marshmallow(object):
 
         # If using Flask-SQLAlchemy, attach db.session to SQLAlchemySchema
         if has_sqla and "sqlalchemy" in app.extensions:
-            db = app.extensions["sqlalchemy"].db
+            db = app.extensions["sqlalchemy"]
             if self.SQLAlchemySchema:
                 self.SQLAlchemySchema.OPTIONS_CLASS.session = db.session
             if self.SQLAlchemyAutoSchema:
