@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     flask_marshmallow.fields
     ~~~~~~~~~~~~~~~~~~~~~~~~
@@ -12,7 +11,6 @@ import re
 
 from flask import url_for
 from marshmallow import fields
-from marshmallow.compat import iteritems
 from marshmallow import missing
 
 
@@ -65,24 +63,26 @@ def _get_value_for_key(obj, key, default):
 class URLFor(fields.Field):
     """Field that outputs the URL for an endpoint. Acts identically to
     Flask's ``url_for`` function, except that arguments can be pulled from the
-    object to be serialized.
+    object to be serialized, and ``**values`` should be passed to the ``values``
+    parameter.
 
     Usage: ::
 
-        url = URLFor('author_get', id='<id>')
-        https_url = URLFor('author_get', id='<id>', _scheme='https', _external=True)
+        url = URLFor('author_get', values=dict(id='<id>'))
+        https_url = URLFor('author_get', values=dict(id='<id>', _scheme='https', _external=True))
 
     :param str endpoint: Flask endpoint name.
-    :param kwargs: Same keyword arguments as Flask's url_for, except string
+    :param dict values: Same keyword arguments as Flask's url_for, except string
         arguments enclosed in `< >` will be interpreted as attributes to pull
         from the object.
+    :param kwargs: keyword arguments to pass to marshmallow field (e.g. ``required``).
     """
 
     _CHECK_ATTRIBUTE = False
 
-    def __init__(self, endpoint, **kwargs):
+    def __init__(self, endpoint, values=None, id=None, **kwargs):
         self.endpoint = endpoint
-        self.params = kwargs
+        self.values = values or {}
         fields.Field.__init__(self, **kwargs)
 
     def _serialize(self, value, key, obj):
@@ -90,7 +90,7 @@ class URLFor(fields.Field):
         ``__init__``.
         """
         param_values = {}
-        for name, attr_tpl in iteritems(self.params):
+        for name, attr_tpl in self.values.items():
             attr_name = _tpl(str(attr_tpl))
             if attr_name:
                 attribute_value = _get_value(obj, attr_name, default=missing)
@@ -114,9 +114,12 @@ UrlFor = URLFor
 class AbsoluteURLFor(URLFor):
     """Field that outputs the absolute URL for an endpoint."""
 
-    def __init__(self, endpoint, **kwargs):
-        kwargs["_external"] = True
-        URLFor.__init__(self, endpoint=endpoint, **kwargs)
+    def __init__(self, endpoint, values=None, **kwargs):
+        if values:
+            values["_external"] = True
+        else:
+            values = {"_external": True}
+        URLFor.__init__(self, endpoint=endpoint, values=values, **kwargs)
 
 
 AbsoluteUrlFor = AbsoluteURLFor
@@ -127,9 +130,7 @@ def _rapply(d, func, *args, **kwargs):
     if isinstance(d, (tuple, list)):
         return [_rapply(each, func, *args, **kwargs) for each in d]
     if isinstance(d, dict):
-        return {
-            key: _rapply(value, func, *args, **kwargs) for key, value in iteritems(d)
-        }
+        return {key: _rapply(value, func, *args, **kwargs) for key, value in d.items()}
     else:
         return func(d, *args, **kwargs)
 
@@ -152,7 +153,7 @@ class Hyperlinks(fields.Field):
     Example: ::
 
         _links = Hyperlinks({
-            'self': URLFor('author', id='<id>'),
+            'self': URLFor('author', values=dict(id='<id>')),
             'collection': URLFor('author_list'),
         })
 
@@ -160,7 +161,7 @@ class Hyperlinks(fields.Field):
 
         _links = Hyperlinks({
             'self': {
-                'href': URLFor('book', id='<id>'),
+                'href': URLFor('book', values=dict(id='<id>')),
                 'title': 'book detail'
             }
         })
